@@ -63,6 +63,24 @@ def get_fc_optional(ctx):
     click.echo(cmplrs.get_fc_optional())
 
 
+@dh_fortran.command("get_flibdir", help="Returns flibdir for a given flavor")
+@click.pass_context
+@click.option("--flavor", help="Fortran flavor (eg gfortran-15, flang-21)")
+def get_flibdir(ctx, flavor):
+    cli.verbose_print("dh_fortran get_flibdir called")
+    cli.validate_flavor(flavor)
+    click.echo(cmplrs.get_flibdir(flavor))
+
+
+@dh_fortran.command("get_fmoddir", help="Returns fmoddir for a given flavor")
+@click.option("--flavor", help="Fortran flavor (eg gfortran-15, flang-21)")
+@click.pass_context
+def get_fmoddir(ctx, flavor):
+    cli.verbose_print("dh_fortran get_fmoddir called")
+    cli.validate_flavor(flavor)
+    click.echo(cmplrs.get_fmoddir(flavor))
+
+
 @dh_fortran.command(
     "get_fc_exe", help="Return Fortran executable for specified (or default) flavor"
 )
