@@ -14,7 +14,7 @@ def test_get_flavor():
     gf = cp.default_compilers["gfortran"]
     assert cp.get_fc_flavor("/usr/bin/gfortran") == gf
     assert cp.get_fc_flavor("/usr/bin/gfortran-15") == gf
-    assert cp.get_fc_flavor(f"/usr/bin/{cp._multiarch}-gfortran-15") == gf
+    assert cp.get_fc_flavor(f"/usr/bin/{cp.multiarch}-gfortran-15") == gf
     assert cp.get_fc_flavor("/etc/alternatives/f95") == gf
 
     try:
@@ -31,9 +31,6 @@ def test_get_fc_default():
     assert cp.get_fc_default() == gf
 
 
-def test_get_fort_root():
-    assert cp.get_fort_root() == f"/usr/lib/{cp._multiarch}/fortran"
-
 
 def test_get_optional():
     assert cp.get_fc_optional() is not None
